var core = require('@raam/core');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var flexboxRecipes = {
  vStack: {
    flexDirection: "column",
    flexWrap: "nowrap"
  },
  hStack: {
    flexDirection: "row",
    flexWrap: "nowrap"
  },
  wrap: {
    alignItems: "center",
    flexDirection: "row",
    flexWrap: "wrap",
    justifyContent: "flex-start"
  }
};

var _parent = function parent(_ref) {
  var gap = _ref.gap,
      flexDirection = _ref.flexDirection,
      flexWrap = _ref.flexWrap,
      props = _objectWithoutPropertiesLoose(_ref, ["gap", "flexDirection", "flexWrap"]);

  return _extends({}, core.setFlexGap({
    element: "parent",
    value: gap
  }), core.setFlexReset("parent"), core.setFlexBase("parent"), core.setFlexDirection(flexDirection), core.setFlexWrap(flexWrap), props);
};

var _child = function child(_ref2) {
  var _ref2$flex = _ref2.flex,
      flex = _ref2$flex === void 0 ? "0 0 auto" : _ref2$flex,
      flexBasis = _ref2.flexBasis,
      flexGrow = _ref2.flexGrow,
      flexShrink = _ref2.flexShrink,
      _ref2$index = _ref2.index,
      index = _ref2$index === void 0 ? 1 : _ref2$index;
  var element = index > 0 ? "nthChild" : "firstChild";
  return _extends({}, core.setFlexReset(element), core.setFlexBase(element), core.setFlexGap({
    element: element
  }), {
    flex: flex,
    flexBasis: flexBasis,
    flexGrow: flexGrow,
    flexShrink: flexShrink
  });
};

var flexbox = function flexbox(props) {
  return {
    parent: function parent() {
      return _parent(_extends({}, props));
    },
    child: function child(childProps) {
      if (childProps === void 0) {
        childProps = {};
      }

      return _child(_extends({}, childProps, props));
    }
  };
};

exports.flexbox = flexbox;
exports.flexboxRecipes = flexboxRecipes;
//# sourceMappingURL=index.js.map
