import { setFlexGap, setFlexReset, setFlexBase, setFlexDirection, setFlexWrap } from '@raam/core';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

const flexboxRecipes = {
  vStack: {
    flexDirection: "column",
    flexWrap: "nowrap"
  },
  hStack: {
    flexDirection: "row",
    flexWrap: "nowrap"
  },
  wrap: {
    alignItems: "center",
    flexDirection: "row",
    flexWrap: "wrap",
    justifyContent: "flex-start"
  }
};

const parent = (_ref) => {
  let {
    gap,
    flexDirection,
    flexWrap
  } = _ref,
      props = _objectWithoutPropertiesLoose(_ref, ["gap", "flexDirection", "flexWrap"]);

  return _extends({}, setFlexGap({
    element: "parent",
    value: gap
  }), setFlexReset("parent"), setFlexBase("parent"), setFlexDirection(flexDirection), setFlexWrap(flexWrap), props);
};

const child = ({
  flex: _flex = "0 0 auto",
  flexBasis,
  flexGrow,
  flexShrink,
  index: _index = 1
}) => {
  const element = _index > 0 ? "nthChild" : "firstChild";
  return _extends({}, setFlexReset(element), setFlexBase(element), setFlexGap({
    element
  }), {
    flex: _flex,
    flexBasis,
    flexGrow,
    flexShrink
  });
};

const flexbox = props => ({
  parent: () => parent(_extends({}, props)),
  child: (childProps = {}) => child(_extends({}, childProps, props))
});

export { flexbox, flexboxRecipes };
//# sourceMappingURL=index.modern.js.map
